@@ -1,6 +1,6 @@
 package JSON::RPC;
 use strict;
-our $VERSION = '1.00';
+our $VERSION = '1.00_01';
 
 1;
 
@@ -14,16 +14,16 @@ JSON::RPC - JSON RPC 2.0 Server Implementation
 
     # app.psgi
     use strict;
-    use JSON::RPC::Dispatch;
+    use JSON::RPC::Dispatcher;
 
-    my $dispatch = JSON::RPC::Dispatch->new(
+    my $dispatcher = JSON::RPC::Dispatcher->new(
         prefix => "MyApp::JSONRPC::Handler",
         router => Router::Simple->new( ... )
     );
 
     sub {
         my $env = shift;
-        $dispatch->handle_psgi($env);
+        $dispatcher->handle_psgi($env);
     };
 
 =head1 DESCRIPTION
@@ -36,11 +36,7 @@ JSON::RPC is a set of modules that implment JSON RPC 2.0 protocol.
 
 =head1 BASIC USAGE
 
-The JSON::RPC::Dispatch object is responsible for marshalling the request.
-
-    my $dispatch = JSON::RPC::Dispatch->new(
-        router => ...,
-    );
+The dispatcher is responsible for marshalling the request.
 
 The routing between the JSON RPC methods and their implementors are handled by
 Router::Simple. For example, if you want to map method "foo" to a "MyApp::JSONRPC::Handler" object instance's "handle_foo" method, you specify something like the following in your router instance:
@@ -53,13 +49,9 @@ Router::Simple. For example, if you want to map method "foo" to a "MyApp::JSONRP
         };
     };
 
-    my $dispatch = JSON::RPC::Dispatch->new(
-        router => $router,
-    );
+The "+" prefix in the handler classname denotes that it is already a fully qualified classname. Without the prefix, the value of "prefix" in the dispatcher object will be used to qualify the classname. If you specify it in your Dispatcher instance, you may omit the prefix part to save you some typing:
 
-The "+" prefix in the handler classname denotes that it is already a fully qualified classname. Without the prefix, the value of "prefix" in the dispatch object will be used to qualify the classname. If you specify it in your Dispatch instance, you may omit the prefix part to save you some typing:
-
-    use JSON::RPC::Dispatch;
+    use JSON::RPC::Dispatcher;
     use Router::Simple::Declare;
 
     my $router = router {
@@ -72,7 +64,7 @@ The "+" prefix in the handler classname denotes that it is already a fully quali
             action => "process"
         }
     };
-    my $dispatch = JSON::RPC::Dispatch->new(
+    my $dispatcher = JSON::RPC::Dispatcher->new(
         prefix => "MyApp::JSONRPC::Handler",
         router => $router,
     );
@@ -123,7 +115,7 @@ $procedure is an instance of JSON::RPC::Procedure. Use it if you need to figure
 
     # app.psgi
     sub {
-        $dispatch->handle_psgi($env, "arg1", "arg2", "arg3");
+        $dispatcher->handle_psgi($env, "arg1", "arg2", "arg3");
     }
 
 will cause your handlers to receive the following arguments:
@@ -147,8 +139,8 @@ For example, if you would like to your webapp's "rpc" handler to marshall the JS
     sub rpc {
         my ($self, $context) = @_;
 
-        my $dispatch =  ...; # grab it from somewhere
-        $dispatch->handle_psgi( $context->env );
+        my $dispatcher =  ...; # grab it from somewhere
+        $dispatcher->handle_psgi( $context->env );
     }
 
 =head1 BACKWARDS COMPATIBILITY
